function [t,y] = eulers(fun,t0,tend,y0,delta)
% Euler's Method
% INPUTS
% fun = function
% t0 = The initial t
% tend = The final t
% y0 = y(0)
% delta = time step

t = [t0:delta:tend];
y = zeros(1,length(t));

y(1,1) = y0;

for i = 2:length(t)
    t(i) = t(i-1)+delta;
    y(:,i) = y(:,i-1)+delta*feval(fun, t(i-1),y(:,i-1));
end
